@@ -11,10 +11,7 @@ from pygments.lexer import RegexLexer, bygroups, combined, include
 class WomaLexer(RegexLexer):
     name = 'woma'
     mimetype = 'text/woma'
-
-    def __init__(self, startinline=True, **options):
-        options.update(startinline=startinline)
-        super(WomaLexer).__init__(**options)
+    startinline = True
 
     def innerstring_rules(ttype):
         return [
